@@ -12,10 +12,11 @@
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
-import os
 import sys
+from pathlib import Path
 
-sys.path.insert(0, os.path.abspath('..'))
+# insert more formally, explicitly
+sys.path.insert(0, str((Path(__file__).parent / '..').absolute()))
 import sphinx_rtd_theme
 
 # -- Project information -----------------------------------------------------
@@ -25,7 +26,7 @@ copyright = '2021, Pradyumna Paranjape'
 author = 'Pradyumna Paranjape'
 
 # The full version, including alpha/beta/rc tags
-release = '1!1.2.0'
+release = '1!1.2.2'
 
 # -- General configuration ---------------------------------------------------
 
@@ -35,7 +36,7 @@ release = '1!1.2.0'
 extensions = [
     'sphinx.ext.todo', 'sphinx.ext.autodoc', 'sphinx.ext.napoleon',
     'sphinx.ext.viewcode', 'sphinx_rtd_theme', "sphinx_autodoc_typehints",
-    "sphinx_panels"
+    'sphinx_panels'
 ]
 
 # Add any paths that contain templates here, relative to this directory.
