@@ -117,6 +117,13 @@ class InfoMark():
             (str(self.pref.style), self.pref.pref[0], self.pref.pref[1],
              self.text.style + "<CUSTOM>" + ANSI.RESET_ALL))
 
+    def __eq__(self, other, /) -> bool:
+        if any(
+                getattr(self, attr) != getattr(other, attr)
+                for attr in ('pref', 'text')):
+            return False
+        return True
+
     def get_info(self) -> str:  # pragma: no cover
         '''
         Print information about ``InfoMark``
