@@ -71,6 +71,25 @@ class AnsiEffect():
         except KeyError:
             raise BadBGCol(bgcol) from None
 
+    def __eq__(self, other, /) -> bool:
+        if any(
+                getattr(self, attr) != getattr(other, attr)
+                for attr in ('color', 'gloss', 'bgcol')):
+            return False
+        return True
+
+    def __str__(self) -> str:
+        '''
+        Human readable form
+        '''
+        return self.style
+
+    def __repr__(self) -> str:  # pragma: no cover
+        '''
+        repr(self)
+        '''
+        return ' '.join((repr(self.color), repr(self.gloss), repr(self.bgcol)))
+
     @staticmethod
     def inherit(parent):
         '''
@@ -88,18 +107,6 @@ class AnsiEffect():
         '''
         return self.color + self.bgcol + self.gloss
 
-    def __str__(self) -> str:
-        '''
-        Human readable form
-        '''
-        return self.style
-
-    def __repr__(self) -> str:  # pragma: no cover
-        '''
-        repr(self)
-        '''
-        return ' '.join((repr(self.color), repr(self.gloss), repr(self.bgcol)))
-
 
 class PrintPref():
     '''
@@ -154,6 +161,19 @@ class PrintPref():
             pad_len[idx] += max(pad_max[idx] - len(pref_type), 0)
         self.pad = [' ' * (span + 1) for span in pad_len]
 
+    def __eq__(self, other, /) -> bool:
+        if any(
+                getattr(self, attr) != getattr(other, attr)
+                for attr in ('pad', 'brackets', 'pref', 'style')):
+            return False
+        return True
+
+    def __len__(self) -> int:  # pragma: no cover
+        '''
+        length of prefix
+        '''
+        return len(self.pref[0])
+
     @staticmethod
     def _inherit(
             parent=None,
@@ -170,12 +190,6 @@ class PrintPref():
         pref[1] = pref[1] or parent.pref[1]
         return parent.style, pref
 
-    def __len__(self) -> int:  # pragma: no cover
-        '''
-        length of prefix
-        '''
-        return len(self.pref[0])
-
     def to_str(self, **kwargs) -> str:
         '''
         Print prefix with style
